@@ -1,24 +1,16 @@
 '''
-organization
-============
+Organizations
+=============
+
 The following methods allow for interaction with the Tenable.sc
 :sc-api:`Organization <Organization.html>` API. These items are typically seen
 under the **Organization** section of Tenable.sc.
+
 Methods available on ``sc.organizations``:
+
 .. rst-class:: hide-signature
 .. autoclass:: OrganizationAPI
-    .. automethod:: create
-    .. automethod:: list
-    .. automethod:: details
-    .. automethod:: edit
-    .. automethod:: delete
-    .. automethod:: accept_risk_rules
-    .. automethod:: recast_risk_rules
-    .. automethod:: manager_create
-    .. automethod:: manager_delete
-    .. automethod:: manager_details
-    .. automethod:: manager_edit
-    .. automethod:: managers_list
+    :members:
 '''
 from tenable.sc.base import SCEndpoint
 
@@ -140,7 +132,9 @@ class OrganizationAPI(SCEndpoint):
     def create(self, name, **kwargs):
         '''
         Create a new organization
+
         :sc-api:`SC Organization Create <Organization.html#organization_POST>`
+
         Args:
             name (str): The name for organization.
             info_links (list, optional):
@@ -180,20 +174,30 @@ class OrganizationAPI(SCEndpoint):
             zone_selection (str):
                 What type of scan zone selection should be performed?
                 Available selection types are as follows: ``auto_only``,
-                ``locked``, ``selectable+auto``, ``selectable+auto_restricted``.
+                ``locked``, ``selectable+auto``,
+                ``selectable+auto_restricted``.
                 If left unspecified, the default is ``auto_only``.
             zones (list, optional):
                 When ``zone_selection`` is not ``auto_only``, this field
                 must be filled with list of ids from available scan zone(s).
+
         Returns:
             :obj:`dict`:
                 The organization resource record for the newly created Org.
+
         Examples:
+
             Creating a new organization with automatic scan zone selection:
+
             >>> org = sc.organization.create('Sample Organization')
+
             Creating a new organization with custom analysis links:
-            >>> org = sc.organization.create('Sample Organization', info_links=[
-            ...     ('SANS', 'https://isc.sans.edu/ipinfo.html?ip=%IP%')])
+
+            >>> org = sc.organization.create(
+            ...     'Sample Organization',
+            ...     info_links=[
+            ...         ('SANS', 'https://isc.sans.edu/ipinfo.html?ip=%IP%')
+            ... ])
         '''
         kwargs['name'] = name
         kwargs['zone_selection'] = kwargs.get('zone_selection', 'auto_only')
@@ -203,17 +207,23 @@ class OrganizationAPI(SCEndpoint):
     def list(self, fields=None):
         '''
         Retrieves a list of organizations.
-        :sc-api:`SC organization List <Organization.html#OrganizationRESTReference-/organization>`
+
+        :sc-api:`SC organization List <Organization.html#OrganizationRESTReference-/organization>`  # noqa: E501
+
         Args:
             fields (list, optional):
-                The list of fields that are desired to be returned.  For details
-                on what fields are available, please refer to the details on the
-                request within the organization list API doc.
+                The list of fields that are desired to be returned.  For
+                details on what fields are available, please refer to the
+                details on the request within the organization list API doc.
+
         Returns:
             :obj:`list`:
                 List of organization definitions.
+
         Examples:
+
             Retrieve all of all of the organizations:
+
             >>> repos = sc.organizations.list()
         '''
         params = dict()
@@ -225,31 +235,40 @@ class OrganizationAPI(SCEndpoint):
     def details(self, organization_id, fields=None):
         '''
         Retrieves the details for the specified organization.
-        :sc-api:`SC Organization Details <Organization.html#organization_id_GET>`
+
+        :sc-api:`SC Organization Details <Organization.html#organization_id_GET>`  # noqa: E501
+
         Args:
             organization_id (int): The numeric id of the organization.
             fields (list, optional):
                 The list of fields that are desired to be returned. For details
                 on what fields are available, please refer to the details on
                 the request within the organization details API doc.
+
         Returns:
             :obj:`dict`:
                 The organization resource record.
+
         Examples:
+
             >>> org = sc.organization.details(1)
         '''
         params = dict()
         if fields:
-            params['fields'] = ','.join([self._check('field', f, str) for f in fields])
+            params['fields'] = ','.join(
+                [self._check('field', f, str) for f in fields]
+            )
 
         return self._api.get('organization/{}'.format(
-            self._check('organization_id', organization_id, int)), params=params).json()['response']
+            self._check('organization_id', organization_id, int)),
+            params=params).json()['response']
 
     def edit(self, organization_id, **kwargs):
-        '''Updates an existing organization
-        Edits the Organization associated with {organization_id}, changing only the passed
-        in fields.
-        :sc-api:`SC Organization Edit <Organization.html#organization_id_PATCH>`
+        '''
+        Updates an existing organization
+
+        :sc-api:`SC Organization Edit <Organization.html#organization_id_PATCH>`  # noqa: E501
+
         Args:
             organization_id: The numeric id of the organization.
             info_links (list, optional):
@@ -293,9 +312,12 @@ class OrganizationAPI(SCEndpoint):
             zones (list, optional):
                 When ``zone_selection`` is not ``auto_only``, this field
                 must be filled with list of ids from available scan zone(s).
+
         Returns:
             dict: The updated organization resource record.
+
         Examples:
+
             >>> sc.organization.edit(1, name='New Name')
         '''
         kwargs = self._constructor(**kwargs)
@@ -305,24 +327,37 @@ class OrganizationAPI(SCEndpoint):
     def delete(self, organization_id):
         '''
         Remove the specified organization from Tenable.sc
-        :sc-api:`SC organization Delete <Organization.html#organization_id_DELETE>`
+
+        :sc-api:`SC organization Delete <Organization.html#organization_id_DELETE>`  # noqa: E501
+
         Args:
             organization_id (int): The numeric id of the organization to delete.
+
         Returns:
             :obj:`str`:
                 Empty response string
+
         Examples:
+
             >>> sc.organization.delete(1)
         '''
         return self._api.delete('organization/{}'.format(
-            self._check('organization_id', organization_id, int))).json()['response']
+            self._check('organization_id', organization_id, int))
+        ).json()['response']
 
-    def accept_risk_rules(self, organization_id, repos=None, plugin=None, port=None):
+    def accept_risk_rules(self,
+                          organization_id,
+                          repos=None,
+                          plugin=None,
+                          port=None
+                          ):
         '''
         Retrieves the accepted risk rules for the organization and optionally
         will filter based on the parameters specified.
+
         :sc-api:`organization: accept-risk-rule
-        <Organization.html#OrganizationRESTReference-/organization/{organization_id}/acceptRiskRule>`
+        <Organization.html#OrganizationRESTReference-/organization/{organization_id}/acceptRiskRule>`  # noqa: E501
+
         Args:
             organization_id (int): The organization id.
             repos (list, optional):
@@ -331,10 +366,13 @@ class OrganizationAPI(SCEndpoint):
                 A plugin id to restrict the search to.
             port (int, optional):
                 A port number to restrict the search to.
+
         Returns:
             :obj:`list`:
                 A list of rules that match the request.
+
         Examples:
+
             >>> for rule in sc.organizations.accept_risk_rules(1):
             ...     pprint(rule)
         '''
@@ -353,8 +391,10 @@ class OrganizationAPI(SCEndpoint):
         '''
         Retrieves the recasted risk rules for the organization and optionally
         will filter based on the parameters specified.
+
         :sc-api:`organization: recast-risk-rule
-        <Organization.html#OrganizationRESTReference-/organization/{organization_id}/recastRiskRule>`
+        <Organization.html#OrganizationRESTReference-/organization/{organization_id}/recastRiskRule>`  # noqa: E501
+
         Args:
             organization_id (int): The organization id.
             repos (list, optional):
@@ -363,10 +403,13 @@ class OrganizationAPI(SCEndpoint):
                 A plugin id to restrict the search to.
             port (int, optional):
                 A port number to restrict the search to.
+
         Returns:
             :obj:`list`:
                 A list of rules that match the request.
+
         Examples:
+
             >>> for rule in sc.organizations.recast_risk_rules(1):
             ...     pprint(rule)
         '''
@@ -384,7 +427,9 @@ class OrganizationAPI(SCEndpoint):
     def managers_list(self, org_id, fields=None):
         '''
         Retrieves a list of security managers.
-        :sc-api:`organization-security-manager: list <Organization-Security-Manager.html#OrganizationSecurityManagerRESTReference-/organization/{orgID}/securityManager>`
+
+        :sc-api:`organization-security-manager: list <Organization-Security-Manager.html#OrganizationSecurityManagerRESTReference-/organization/{orgID}/securityManager>`  # noqa: E501,PLC0301
+
         Args:
             org_id: (int):
                 The numeric identifier for the organization.
@@ -392,10 +437,13 @@ class OrganizationAPI(SCEndpoint):
                 The list of fields that are desired to be returned.  For details
                 on what fields are available, please refer to the details on the
                 request within the organization list API doc.
+
         Returns:
             :obj:`list`:
                 List of user definitions.
+
         Examples:
+
             Retrieve all of the security managers for a given org.:
             >>> repos = sc.organizations.managers_list()
         '''
@@ -411,7 +459,9 @@ class OrganizationAPI(SCEndpoint):
         Creates a new security manager for the given org.  For a complete list
         of parameters that are supported for this call, please refer to
         :py:meth:`tio.users.create() <UserAPI.create>` for more details.
-        :sc-api:`organization-security-manager: create <Organization-Security-Manager.html#organization_orgID_securityManager_POST>`
+
+        :sc-api:`organization-security-manager: create <Organization-Security-Manager.html#organization_orgID_securityManager_POST>`  # noqa: E501,PLC0301
+
         Args:
             org_id: (int):
                 The numeric identifier for the organization.
@@ -423,10 +473,13 @@ class OrganizationAPI(SCEndpoint):
                 The role that should be assigned to this user.
             **kwargs (dict):
                 The keyword args to pass to the user constructor.
+
         Returns:
             :obj:`dict`:
                 The newly created security manager.
+
         Examples:
+
             >>> secmngr = sc.organizations.manager_create(1,
             ...     'username', 'password', 1)
         '''
@@ -443,7 +496,9 @@ class OrganizationAPI(SCEndpoint):
         '''
         Retrieves the details of a specified security manager within a
         specified organization.
-        :sc-api:`organization-security-manager: details <Organization-Security-Manager.html#OrganizationSecurityManagerRESTReference-/organization/{orgID}/securityManager/{id}>`
+
+        :sc-api:`organization-security-manager: details <Organization-Security-Manager.html#OrganizationSecurityManagerRESTReference-/organization/{orgID}/securityManager/{id}>`  # noqa: E501,PLC0301
+
         Args:
             org_id: (int):
                 The numeric identifier for the organization.
@@ -453,10 +508,13 @@ class OrganizationAPI(SCEndpoint):
                 The list of fields that are desired to be returned.  For details
                 on what fields are available, please refer to the details on the
                 request within the organization list API doc.
+
         Returns:
             :obj:`dict`:
                 The user resource record.
+
         Examples:
+
             >>> secmngr = sc.organizations.manager_details(1, 1)
         '''
         params = dict()
@@ -473,7 +531,9 @@ class OrganizationAPI(SCEndpoint):
         Edits the specified security manager within the specified organization.
         For details on the supported arguments that may be passed, please refer
         to :py:meth:`tio.users.edit() <UserAPI.edit>` for more details.
-        :sc-api:`organization-security-manager: edit <Organization-Security-Manager.html#organization_orgID_securityManager_id_PATCH>`
+
+        :sc-api:`organization-security-manager: edit <Organization-Security-Manager.html#organization_orgID_securityManager_id_PATCH>`  # noqa: E501,PLC0301
+
         Args:
             org_id: (int):
                 The numeric identifier for the organization.
@@ -481,10 +541,13 @@ class OrganizationAPI(SCEndpoint):
                 The numeric identifier for the user.
             **kwargs (dict):
                 The keyword args to pass to the user constructor.
+
         Returns:
             :obj:`dict`:
                 The updated user record.
+
         Examples:
+
             >>> secmngr = sc.organizations.manager_edit(1, 1,
             ...     username='updated')
         '''
@@ -497,13 +560,17 @@ class OrganizationAPI(SCEndpoint):
     def manager_delete(self, org_id, user_id, migrate_to=None):
         '''
         Removes the user specified.
-        :sc-api:`organization-security-manager: delete <Organization-Security-Manager.html#organization_orgID_securityManager_id_DELETE>`
+
+        :sc-api:`organization-security-manager: delete <Organization-Security-Manager.html#organization_orgID_securityManager_id_DELETE>`  # noqa: E501,PLC0301
+
         Args:
             org_id: (int):
                 The numeric identifier for the organization.
             user_id: (int):
                 The numeric identifier for the user.
+
         Examples:
+
             >>> sc.organizations.manager_delete(1, 1)
         '''
         payload = dict()
@@ -513,4 +580,4 @@ class OrganizationAPI(SCEndpoint):
         self._api.delete('organization/{}/securityManager/{}'.format(
             self._check('org_id', org_id, int),
             self._check('user_id', user_id, int)
-        ), json=payload)
\ No newline at end of file
+        ), json=payload)
