@@ -1,28 +1,4 @@
-try:
-    from urlparse import urlparse
-except:
-    from urllib.parse import urlparse
-
-
-def dict_merge(master, updates):
-    '''
-    Merge 2 dictionaries together  The updates dictionary will be merged into
-    the master, adding/updating any values as needed.
-
-    Args:
-        master (dict): The master dictionary to be used as the base.
-        updates (dict): The dictionary that will overload the values in the master.
-
-    Returns:
-        dict: The merged dictionary
-    '''
-    for key in updates:
-        if key in master and isinstance(master[key], dict) and isinstance(updates[key], dict):
-            master[key] = dict_merge(master[key], updates[key])
-        else:
-            master[key] = updates[key]
-    return master
-
+from restfly.utils import dict_merge, url_validator
 
 def policy_settings(item):
     '''
@@ -60,12 +36,4 @@ def policy_settings(item):
             resp = dict_merge(resp, policy_settings(item[key]))
 
     # Return the key-value pair.
-    return resp
-
-
-def url_validator(uri):
-    try:
-        r = urlparse(uri)
-        return all([r.scheme, r.netloc])
-    except:
-        return False
\ No newline at end of file
+    return resp
\ No newline at end of file
